Module: RemoteExecutionHelper
- Defined in:
- app/helpers/remote_execution_helper.rb
Overview
rubocop:disable Metrics/ModuleLength
Instance Method Summary collapse
- #advanced_switch_f(default_text, switch_text) ⇒ Object
- #description_checkbox_f(f, job_template, disabled) ⇒ Object
- #description_format_help ⇒ Object
- #description_format_textarea_f(f, job_template, disabled) ⇒ Object
- #documentation_button_rex(section = '') ⇒ Object
- #host_counter(label, count) ⇒ Object
- #invocation_count(invocation, options = {}) ⇒ Object
- #invocation_description(invocation) ⇒ Object
- #invocation_result(invocation, key) ⇒ Object
- #job_hosts_authorizer ⇒ Object
-
#job_invocation_task_buttons(task) ⇒ Object
rubocop:disable Metrics/AbcSize.
- #job_invocations_buttons ⇒ Object
- #link_to_invocation_task_if_authorized(invocation) ⇒ Object
- #load_template_from_task(template_invocation, target) ⇒ Object
- #preview_box(template_invocation, target) ⇒ Object
- #providers_options ⇒ Object
- #remote_execution_provider_for(template_invocation) ⇒ Object
- #template_input_header(f, template) ⇒ Object
- #template_input_types_options ⇒ Object
- #template_invocation_actions(task, host, job_invocation, template_invocation) ⇒ Object
- #template_invocation_status(task) ⇒ Object
-
#template_invocation_task_buttons(task, invocation) ⇒ Object
rubocop:enable Metrics/AbcSize.
- #time_in_words_span(time) ⇒ Object
Instance Method Details
#advanced_switch_f(default_text, switch_text) ⇒ Object
228 229 230 231 232 233 234 235 236 |
# File 'app/helpers/remote_execution_helper.rb', line 228 def advanced_switch_f(default_text, switch_text) content_tag :div, :class => 'form-group' do content_tag(:div, '', :class => 'col-md-2 control-label') + content_tag(:div, :class => 'col-md-4') do content_tag(:i, '', :class => 'fa fa-angle-right') + ' ' + link_to(default_text, '#', :class => 'advanced_fields_switch', :'data-alternative-label' => switch_text) end end end |
#description_checkbox_f(f, job_template, disabled) ⇒ Object
200 201 202 203 204 205 206 207 208 |
# File 'app/helpers/remote_execution_helper.rb', line 200 def description_checkbox_f(f, job_template, disabled) check_box_tag('description_format_override', job_template.generate_description_format, f.object.description_format.nil?, :class => 'description_format_override', :name => f.object_name + '[description_override]', :disabled => disabled, :onchange => 'description_override(this);') + ' ' + _('Use default description template') end |
#description_format_help ⇒ Object
221 222 223 224 225 226 |
# File 'app/helpers/remote_execution_helper.rb', line 221 def description_format_help _('This template is used to generate the description.<br/>' + 'Input values can be used using the syntax %{package}.<br/>' + 'You may also include the job category and template<br/>' + 'name using %{job_category} and %{template_name}.').html_safe # rubocop:disable Rails/OutputSafety end |
#description_format_textarea_f(f, job_template, disabled) ⇒ Object
210 211 212 213 214 215 216 217 218 219 |
# File 'app/helpers/remote_execution_helper.rb', line 210 def description_format_textarea_f(f, job_template, disabled) textarea_f f, 'description_format', :label => _('Description template'), :value => f.object.description_format || job_template.generate_description_format, :rows => 2, :onchange => 'regenerate_description(this);', :class => 'description_format advanced', :disabled => disabled, :label_help => description_format_help end |
#documentation_button_rex(section = '') ⇒ Object
185 186 187 188 189 |
# File 'app/helpers/remote_execution_helper.rb', line 185 def (section = '') url = 'http://theforeman.org/plugins/foreman_remote_execution/' + "#{ForemanRemoteExecution::VERSION.split('.').take(2).join('.')}/index.html#" section, :root_url => url end |
#host_counter(label, count) ⇒ Object
15 16 17 18 19 |
# File 'app/helpers/remote_execution_helper.rb', line 15 def host_counter(label, count) content_tag(:div, :class => 'host_counter') do content_tag(:div, label, :class => 'header') + content_tag(:div, count.to_s, :class => 'count') end end |
#invocation_count(invocation, options = {}) ⇒ Object
139 140 141 142 143 144 145 146 147 148 |
# File 'app/helpers/remote_execution_helper.rb', line 139 def invocation_count(invocation, = {}) = { :unknown_string => 'N/A' }.merge() if invocation.queued? [:unknown_string] elsif [:output_key] == :total_count invocation.total_hosts_count else (invocation.task.try(:output) || {}).fetch([:output_key], [:unknown_string]) end end |
#invocation_description(invocation) ⇒ Object
150 151 152 153 |
# File 'app/helpers/remote_execution_helper.rb', line 150 def invocation_description(invocation) description = invocation.description.try(:capitalize) || invocation.job_category trunc_with_tooltip(description, 80) end |
#invocation_result(invocation, key) ⇒ Object
155 156 157 158 159 160 |
# File 'app/helpers/remote_execution_helper.rb', line 155 def invocation_result(invocation, key) unknown = '—' result = invocation_count(invocation, :output_key => key, :unknown_string => unknown.html_safe) # rubocop:disable Rails/OutputSafety label = key == :failed_count ? 'danger' : 'info' result == unknown ? result : report_event_column(result, "label-#{label}") end |
#job_hosts_authorizer ⇒ Object
11 12 13 |
# File 'app/helpers/remote_execution_helper.rb', line 11 def @job_hosts_authorizer ||= Authorizer.new(User.current, :collection => @hosts) end |
#job_invocation_task_buttons(task) ⇒ Object
rubocop:disable Metrics/AbcSize
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'app/helpers/remote_execution_helper.rb', line 69 def (task) job_invocation = task.task_groups.find { |group| group.class == JobInvocationTaskGroup }.job_invocation = Authorizer.new(User.current, :collection => [task]) = [] if (hash_for_new_job_invocation_path) << link_to(_('Rerun'), rerun_job_invocation_path(:id => job_invocation.id), :class => 'btn btn-default', :title => _('Rerun the job')) end if (hash_for_new_job_invocation_path) << link_to(_('Rerun failed'), rerun_job_invocation_path(:id => job_invocation.id, :failed_only => 1), :class => 'btn btn-default', :disabled => task.sub_tasks.where(:result => %w(error warning)).count.zero?, :title => _('Rerun on failed hosts')) end if (:permission => :view_foreman_tasks, :auth_object => task, :authorizer => ) << link_to(_('Job Task'), foreman_tasks_task_path(task), :class => 'btn btn-default', :title => _('See the last task details')) end if (:permission => :cancel_job_invocations, :auth_object => job_invocation) << link_to(_('Cancel Job'), cancel_job_invocation_path(job_invocation), :class => 'btn btn-danger', :title => _('Try to cancel the job'), :disabled => !task.cancellable?, :method => :post) << link_to(_('Abort Job'), cancel_job_invocation_path(job_invocation, :force => true), :class => 'btn btn-danger', :title => _('Try to abort the job without waiting for the results from the remote hosts'), :disabled => !task.cancellable?, :method => :post) end return end |
#job_invocations_buttons ⇒ Object
61 62 63 64 65 66 |
# File 'app/helpers/remote_execution_helper.rb', line 61 def [ ('3.2ExecutingaJob'), new_link(_('Run Job')) ] end |
#link_to_invocation_task_if_authorized(invocation) ⇒ Object
128 129 130 131 132 133 134 135 136 137 |
# File 'app/helpers/remote_execution_helper.rb', line 128 def (invocation) status = job_invocation_status(invocation, nil, false) if invocation.queued? status else = Authorizer.new(User.current, :collection => [invocation.task]) job_invocation_status(invocation), hash_for_foreman_tasks_task_path(invocation.task).merge(:auth_object => invocation.task, :permission => :view_foreman_tasks, :authorizer => ) end end |
#load_template_from_task(template_invocation, target) ⇒ Object
238 239 240 241 242 |
# File 'app/helpers/remote_execution_helper.rb', line 238 def load_template_from_task(template_invocation, target) task = template_invocation.job_invocation.sub_task_for_host(target) return if task.nil? task.execution_plan.actions[1].try(:input) { |input| input['script'] } end |
#preview_box(template_invocation, target) ⇒ Object
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'app/helpers/remote_execution_helper.rb', line 162 def preview_box(template_invocation, target) renderer = InputTemplateRenderer.new(template_invocation.template, target, template_invocation) if (preview = (load_template_from_task(template_invocation, target) || renderer.preview)) content_tag :pre, preview elsif target.nil? alert :text => _('Could not render the preview because no host matches the search query.'), :class => 'alert alert-block alert-warning base', :close => false else alert :class => 'alert-block alert-danger base in fade has-error', :text => renderer..html_safe # rubocop:disable Rails/OutputSafety end end |
#providers_options ⇒ Object
3 4 5 |
# File 'app/helpers/remote_execution_helper.rb', line 3 def RemoteExecutionProvider.providers.map { |key, provider| [ key, _(provider.humanized_name) ] } end |
#remote_execution_provider_for(template_invocation) ⇒ Object
57 58 59 |
# File 'app/helpers/remote_execution_helper.rb', line 57 def remote_execution_provider_for(template_invocation) template_invocation.nil? ? _('N/A') : template_invocation.template.provider.humanized_name end |
#template_input_header(f, template) ⇒ Object
191 192 193 194 195 196 197 198 |
# File 'app/helpers/remote_execution_helper.rb', line 191 def template_input_header(f, template) header = _('Template input') unless template.locked? header += ' ' + remove_child_link('x', f, {:rel => 'twipsy', :'data-title' => _('remove template input'), :'data-placement' => 'left', :class => 'fr badge badge-danger'}) end header.html_safe # rubocop:disable Rails/OutputSafety end |
#template_input_types_options ⇒ Object
7 8 9 |
# File 'app/helpers/remote_execution_helper.rb', line 7 def TemplateInput::TYPES.map { |key, name| [ _(name), key ] } end |
#template_invocation_actions(task, host, job_invocation, template_invocation) ⇒ Object
42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'app/helpers/remote_execution_helper.rb', line 42 def template_invocation_actions(task, host, job_invocation, template_invocation) host_task = template_invocation.try(:run_host_job_task) [ (_('Host detail'), hash_for_host_path(host).merge(:auth_object => host, :permission => :view_hosts, :authorizer => )), (_('Rerun on %s') % host.name, hash_for_rerun_job_invocation_path(:id => job_invocation, :host_ids => [ host.id ], :authorizer => )), if host_task.present? ( _('Host task'), hash_for_foreman_tasks_task_path(host_task) .merge(:auth_object => host_task, :permission => :view_foreman_tasks) ) end ] end |
#template_invocation_status(task) ⇒ Object
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'app/helpers/remote_execution_helper.rb', line 21 def template_invocation_status(task) if task.nil? icon_text('question', 'N/A', :kind => 'fa') elsif task.state == 'running' icon_text('running', _('running'), :kind => 'pficon') elsif task.state == 'planned' icon_text('build', _('planned'), :kind => 'pficon') else case task.result when 'warning', 'error' icon_text('error-circle-o', _('failed'), :kind => 'pficon') when 'cancelled' icon_text('warning-triangle-o', _('cancelled'), :kind => 'pficon') when 'success' icon_text('ok', _('success'), :kind => 'pficon') else task.result end end end |
#template_invocation_task_buttons(task, invocation) ⇒ Object
rubocop:enable Metrics/AbcSize
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'app/helpers/remote_execution_helper.rb', line 106 def (task, invocation) = [] if (:permission => :view_foreman_tasks, :auth_object => task) << link_to(_('Task Details'), foreman_tasks_task_path(task), :class => 'btn btn-default', :title => _('See the task details')) end if (:permission => :cancel_job_invocations, :auth_object => invocation) << link_to(_('Cancel Job'), cancel_foreman_tasks_task_path(task), :class => 'btn btn-danger', :title => _('Try to cancel the job on a host'), :disabled => !task.cancellable?, :method => :post) << link_to(_('Abort Job'), abort_foreman_tasks_task_path(task), :class => 'btn btn-danger', :title => _('Try to abort the job on a host without waiting for its result'), :disabled => !task.cancellable?, :method => :post) end end |
#time_in_words_span(time) ⇒ Object
176 177 178 179 180 181 182 183 |
# File 'app/helpers/remote_execution_helper.rb', line 176 def time_in_words_span(time) if time.nil? _('N/A') else content_tag :span, (time > Time.now.utc ? _('in %s') : _('%s ago')) % time_ago_in_words(time), { :'data-original-title' => time.try(:in_time_zone), :rel => 'twipsy' } end end |